package ro.ucv.biblioteca;

import org.apache.commons.cli.*;


/**
 * This class used to test Book class.
 * 
 * <p>Title: Biblioteca </p>
 * <p>Description: Managementul Proiectelor Software</p>
 * <p>Copyright: Copyright (c) 2005</p>
 * <p>Company: Universitatea din Craiova</p>
 * 
 * @author Mihai Gabroveanu
 * @created 20 aprilie 2013
 * @version 21.0
 */


public class Main {
    
    /**
     * Provide command line options.
     * 
     * @return The command line options.
     */
    private static Options getCommandLineOptions(){
	Options options = new Options();
	options.addOption("h", "help", false, "Print this usage information");
	options.addOption("t", "title", true, "The book title");
	options.addOption("a", "author", true, "The book author");
	options.addOption("y", "year", true, "The published year.");
	return options;
    }
    
    /**
     * Display help options.
     *  
     * @param options The command line options.
     */
    private static void showHelp(Options options) {
	    HelpFormatter h = new HelpFormatter();
	    h.printHelp("available options as follow:", options);
	    System.exit(-1);
    }

    /**
     * The main program for the Main class.
     * 
     * @param args The command line arguments.
     */
    public static void main(String[] args) {
	String title = "unknown";
	String author = "unknown";
	int year = 2012;
	Options options = getCommandLineOptions();
	
	CommandLineParser parser = new BasicParser();
	CommandLine cmd = null;
	try {
	    cmd = parser.parse( options, args, true);
	} catch (ParseException e) {
	    System.err.println("Parse command line argumets error: " + e.getMessage());
	    System.exit(-1);
	}
	if (cmd.hasOption("h") || args.length < 1){
	    showHelp(options);
	}
	if (cmd.hasOption("t")){
	   title = cmd.getOptionValue("t");
	}
	if (cmd.hasOption("a")){
	    author = cmd.getOptionValue("a");
	}
	if (cmd.hasOption("y")){
	    year = Integer.parseInt(cmd.getOptionValue("y"));
	}
	
	Book book = new Book(title,author, year);
	System.out.println(book);
    }
}
